375 Sq Ft Studio Apartment Makeover *COLOURFUL, BOHO STYLE!* - YouTube
Description: Enjoy the videos and music you love, upload original content, and share it all with friends, family, and the world on YouTube.
Keywords: video, sharing, camera phone, video phone, free, upload

# This tiny NYC apartment goes for $650 a month!

CALEB SIMPSON
•

###

###

NaN / NaN
Back
Search with your voice
Sign in
All Gaming Live Studio apartments Apartments Tiny house movement Home improvement Weather Forecasting Comedy Dogs Tourist destinations Conversation Recently uploaded
6:59 Now playing

### My $7000 New York City Apartment

CALEB SIMPSON
CALEB SIMPSON
•
36K views 3 weeks ago
27:25 Now playing

### Graham Norton Funniest Moments (32) *NEW

Denise F
Denise F
•
2.9M views 1 year ago
26:22 Now playing

### I'm Moving to a Rural Homestead Alone

hannahleeduggan
hannahleeduggan
Verified
•
480K views 6 days ago
2:24 Now playing

### Tiny Apartment In Milan Italy | Micro Studio Apartment Tour | Never Think Too Small

HP Design
HP Design
•
2K views 8 days ago

##
Shorts

### her whole mood changed! #bekind

•
1.7M views

### Toddler has fun copying mommy in the most adorable way ❤️❤️

•
1M views

### Prince Harry Cracking Jokes with the Queen

•
23M views

### $3000 NYC apartment #shorts #nyc

•
565K views

### أشغال بناء المنازل بالأزهر الولفة الدارالبيضاء ??

•
12 views

### Tom Holland STOPS Interview To Watch Zendaya's Arrival #shorts

•
40M views

### Wal-Mart CALLS COPS for PAYING for stranger’s groceries!

•
3.2M views

### Everything i ate to run 16 miles for marathon training

•
11M views
Show more
13:19 Now playing

### ways to make your home feel just a little bit HAPPIER

Paige Wassel
Paige Wassel
•
70K views 5 days ago
16:57 Now playing

### I toured 15 NYC apartments in 72 hours so you don't have to experience this pain.

Kaiti Yoo
Kaiti Yoo
Verified
•
168K views 10 days ago

##
Trending

16:55 Now playing

### Day in the Life of a Japanese Waitress

Paolo fromTOKYO
Paolo fromTOKYO
Verified
•
452K views 1 day ago
19:09 Now playing

### Making an ALL WOOD Scrabble-themed keyboard

Evan and Katelyn
Evan and Katelyn
Verified
•
326K views 1 day ago
32:50 Now playing

### OFFLINETV TRIP TO JAPAN (PART 2)

OfflineTV
OfflineTV
Verified
•
568K views 1 day ago
10:36 Now playing

### 'Bubble Puppy' Decides She's Ready To Live In The World | The Dodo Comeback Kids

The Dodo
The Dodo
Verified
•
389K views 11 hours ago
3:01 Now playing

### BLACKPINK - ‘Shut Down’ M/V

BLACKPINK
BLACKPINK
Official Artist Channel
•
68M views 1 day ago
12:44 Now playing

### Los Angeles Chargers vs. Kansas City Chiefs | Week 2 Game Highlights

NFL
NFL
Verified
•
3.1M views 1 day ago
28:29 Now playing

### Hermitcraft 9: Episode 20 - SERVER SHENANIGANS

Grian
Grian
Verified
•
466K views 7 hours ago
3:00 Now playing

### Typa Girl

BLACKPINK
BLACKPINK
Official Artist Channel
•
5.1M views 1 day ago
7:44 Now playing

### Morgan Myles Stuns Coaches with Leonard Cohen's "Hallelujah" | The Voice Blind Auditions 2022

The Voice
The Voice
Verified
•
497K views 1 day ago
23:27 Now playing

### I Tried BLEACHING My Hair AT HOME Like A Rebellious Teen …but I'm a 30 Year Old Lady (NEW HAIR)

LaurenzSide
LaurenzSide
Verified
•
223K views 6 hours ago
6:05 Now playing

### Version 3.1 "King Deshret and the Three Magi" Trailer | Genshin Impact

Genshin Impact
Genshin Impact
Verified
•
2.1M views 1 day ago
1:47 Now playing

### Oddballs │ Official Trailer │ My Netflix Show

TheOdd1sOut
TheOdd1sOut
Verified
•
2.4M views 1 day ago
10:17 Now playing

### Living Alone Diaries | What I Eat in a Day (simple and easy meals)

Michelle Choi
Michelle Choi
Verified
•
374K views 1 day ago
10:28 Now playing

### Living in a Tiny-House on an NYC Roof…

Cash Jordan
Cash Jordan
Verified
•
494K views 3 weeks ago
12:00 Now playing

### AESTHETIC DESK MAKEOVER | minimal & productive desk set up, organization ideas

Selena Trevino
Selena Trevino
•
82K views 3 weeks ago
13:32 Now playing

### #56 My first winter snow storm living in a van ❄️ (this was a lot)

Mariah Alice
Mariah Alice
•
1.5M views 8 months ago
30:31 Now playing

### In full: Queen's grandchildren hold vigil around the monarch's coffin

Sky News
Sky News
Verified
•
2.6M views Streamed 7 hours ago
42:31 Now playing

### Germany: The discreet lives of the super rich | DW Documentary

DW Documentary
DW Documentary
Verified
•
15M views 3 years ago
11:59 Now playing

### BTS (방탄소년단) 'MIC Drop & BTS (방탄소년단) 'FAKE LOVE' Official MV (REACTION) | 2 IN 1 We're Speechless!

MARSHMALLOWS & MUSIC REACTS
MARSHMALLOWS & MUSIC REACTS
•
52K views 4 days ago
23:34 Now playing

### Family of 4 VAN TOUR ! UNBELIEVABLE Open Layout - Shower, Toilet, Screen Doors! | Van Life

WayOut Railroad
WayOut Railroad
•
242K views 4 weeks ago
Featured
Live TV from 85+ networks
$64.99 per month
Terms apply
Try YouTube TV
Try YouTube TV
Mondays, 8/7c
Try YouTube TV
Mondays, 9/8c
Try YouTube TV
Fridays, 8/7c
12:35 Now playing

### 321 Motor Entrevista a Surhayen Pernía

Felix Ortiz Serrano
Felix Ortiz Serrano
•
525 views 3 days ago
5:04 Now playing

### '뇌성마비 고양이도 평범한 고양이입니다' - BBC News 코리아

BBC News 코리아
BBC News 코리아
Verified
•
435K views 2 weeks ago
59:35 Now playing

### ODESZA - A Moment Apart (Full Album)

ODESZA
ODESZA
Official Artist Channel
•
5.6M views 5 years ago
4:28 Now playing

### Troy vs App State INSANE Ending | 2022 College Football

PSC Highlights
PSC Highlights
•
19K views 1 hour ago
10:02 Now playing

### The Most Priceless Moments That Will Melt Your Heart | Emotional Reactions

Will Be OK
Will Be OK
Verified
•
499K views 4 weeks ago
Now playing

### Charles III Proclamation LIVE | Queen Elizabeth II Death | Buckingham Palace Live | News18 LIVE

CNN-News18
CNN-News18
Verified
•
424 watching
LIVE
375 Sq Ft Studio Apartment Makeover *COLOURFUL, BOHO STYLE!*
If playback doesn't begin shortly, try restarting your device.
Includes paid promotion
2:44
0:00 / 41:41•Watch full video
You're signed out
Videos you watch may be added to the TV's watch history and influence TV recommendations. To avoid this, cancel and sign in to YouTube on your computer.
Next (SHIFT+n)
Expand (i)
30:27
0:00
41:41
Up next
Live
Upcoming
Play Now
Alexandra Gater
SUBSCRIBE
Alexandra Gater
SUBSCRIBE
SUBSCRIBED
I am an editor, stylist and home decor expert from Toronto and am passionate about showing millennials it’s possible to live in a home that feels stylish and beautiful (even if you rent!)
Decor Shop With Me In Marrakech | Travel Vlog!
20:20
Share
Include playlist
An error occurred while retrieving sharing information. Please try again later.
From Alexandra Gater
16

## Studio Fix

- by Alexandra Gater
- 16 videos

0:00
41:41
0:01 / 41:41•Watch full video
New!
Watch ads now so you can enjoy fewer interruptions
Got it

## Description

Thank you to Desenio for sponsoring this video! Click the link and use my code ALEXANDRAGATER40 for a 40% discount on prints, excluding personalized items. https://desen.io/alexandragater40 Valid until 11:59pm on September 21st. Hey guys! I'm Alexandra Gater and I show you how to do rental-friendly upgrades and DIY projects on a budget. New videos every Saturday! Today I'm turning this 375 sq ft tiny studio apartment into a boho dream with tons of bold colour. Even though this tiny studio is all open, I was able to create designated areas for the bedroom, living room and office using functional storage solutions (like the brilliant Ikea Kallax!) I hope you love this makeover! Shop my virtual makeover packages: https://bit.ly/3gBHege Kim White’s Space: https://youtu.be/_6z2SII3nHc Products mentioned in this video: Links marked with a AF are affiliate links. That means I receive a percentage of the revenue made from purchasing products through this link. Products marked with * means they were gifted to me from brands but I was not paid to feature them in this video. Canadian Links: Urban Gardener: https://bit.ly/3BMn7XQ * Paint: https://bit.ly/3LoC06c * Label protector: https://fave.co/3drmppD AF Wallpaper: https://etsy.me/3xwzwwy * Desk: https://bit.ly/3QjfyMY * Rattan pendant: Homesense https://bit.ly/3EriK3e * Rug: https://bit.ly/3DxJCRM * Sofa: https://bit.ly/3zsptJ7 * Coffee table: https://bit.ly/3SzPdMC * Mirror: https://bit.ly/3RXEg6U Wall planter: https://bit.ly/3dizwte * Wall sconce: https://bit.ly/3SrLOP9 * Art print 1: https://bit.ly/3DxGYeP * Art print 2: https://bit.ly/3QTMoDQ * Art print 3: https://bit.ly/3LiSDQA * Bedding: https://etsy.me/3qGkCQN Bed cushions: https://bit.ly/3qIon87 * Bed lumbar cushion: https://bit.ly/3Bkzj0J * Frame 1: https://bit.ly/3xuACZZ * Frame 2: https://bit.ly/3xuBpds * Desk chair: Homesense https://bit.ly/3EriK3e * Entryway hooks: https://bit.ly/3BOSyRG * Bar stools: https://fave.co/3qMIhiy AF * Sofa cushion 1: https://bit.ly/3BMpSIG * Sofa cushion 2: https://bit.ly/3ROUzm5 * Floor pillows: https://fave.co/3LsnFFO AF U.S. Links: Urban Gardener: https://bit.ly/3BMn7XQ * Paint: https://bit.ly/3UfPncI * Label protector: https://fave.co/3Lmwm4b AF Wallpaper: https://etsy.me/3xwzwwy * Desk: https://bit.ly/3QjfyMY * Rattan pendant: Homesense https://bit.ly/3EriK3e * Rug: https://bit.ly/3DxJCRM * Sofa: https://bit.ly/3zsptJ7 * Coffee table: https://bit.ly/3SzPdMC * Mirror: https://bit.ly/3RXEg6U Wall planter: https://bit.ly/3dizwte * Wall sconce: https://bit.ly/3SrLOP9 * Art print 1: https://bit.ly/3DxGYeP * Art print 2: https://bit.ly/3QTMoDQ * Art print 3: https://bit.ly/3LiSDQA * Bedding: https://etsy.me/3qGkCQN Bed cushions: https://bit.ly/3qIon87 * Bed lumbar cushion: https://bit.ly/3Bkzj0J * Frame 1: https://bit.ly/3xuACZZ * Frame 2: https://bit.ly/3xuBpds * Desk chair: Homesense https://bit.ly/3EriK3e * Entryway hooks: https://bit.ly/3BOSyRG * Bar stools: https://fave.co/3QPOsge AF * Sofa cushion 1: https://bit.ly/3BMpSIG * Sofa cushion 2: https://bit.ly/3ROUzm5 * Floor pillows: https://fave.co/3qKVlER AF Let's be friends: TikTok: https://tiktok.com/@alexandragateroff... Instagram: https://instagram.com/alexandragater Pinterest: https://pinterest.ca/alexandragater Shop my Amazon store Canada: https://amazon.ca/shop/alexandragater Shop my Amazon store U.S.: https://amazon.com/shop/alexandragater Sign up to my newsletter to get decor tips and products in your inbox every week: https://alexandragater.com Retro label maker I use: https://amzn.to/2j7Ukk8 * GET IN TOUCH: Alexandra Gater P.O. Box 68555 Walmer Toronto, ON M5S 3C9 EMAIL: alexandra@alexandragater.com Thank you so much to each and every one of you for your continued support. I get to make these videos for a living, and I couldn’t be more thrilled about it. Videographer, Carla Antonio: http://carlaantonio.com Senior Editor, James Resendes: https://vimeo.com/jamesresendes Junior editor/vlog editor, Alessandra Sconza https://vimeo.com/asconza Intro designed and animated by Lindsey Deschamps: https://lindseydes.com All music sourced by licensing. All opinions are my own. It's important to hire licensed professionals for certain projects; if you're unsure or unqualified, please don't attempt any projects seen in my videos yourself.
Show less Show more

## Comments 820

## Transcript

###

###

NaN / NaN

# 375 Sq Ft Studio Apartment Makeover *COLOURFUL, BOHO STYLE!*

113,815 views • Sep 17, 2022
113,815 views Sep 17, 2022 Thank you to Desenio for sponsoring this video! Click the link and use my code ALEXANDRAGATER40 for a 40% discount on prints, excluding personalized items. …...more
...more
Show less
Alexandra Gater
Alexandra Gater
Verified
479K subscribers
Subscribe
Comments
820
AG envisions the creations and Graham builds them!! What genius teamwork. And as we have all said before: Graham is a keeper!

# 375 Sq Ft Studio Apartment Makeover *COLOURFUL, BOHO STYLE!*

113,815 views113K views
Sep 17, 2022
Alexandra Gater
Alexandra Gater
Verified
479K subscribers
Subscribe
Thank you to Desenio for sponsoring this video! Click the link and use my code ALEXANDRAGATER40 for a 40% discount on prints, excluding personalized items. https://desen.io/alexandragater40 Valid until 11:59pm on September 21st. Hey guys! I'm Alexandra Gater and I show you how to do rental-friendly upgrades and DIY projects on a budget. New videos every Saturday! Today I'm turning this 375 sq ft tiny studio apartment into a boho dream with tons of bold colour. Even though this tiny studio is all open, I was able to create designated areas for the bedroom, living room and office using functional storage solutions (like the brilliant Ikea Kallax!) I hope you love this makeover! Shop my virtual makeover packages: https://bit.ly/3gBHege Kim White’s Space: https://youtu.be/_6z2SII3nHc Products mentioned in this video: Links marked with a AF are affiliate links. That means I receive a percentage of the revenue made from purchasing products through this link. Products marked with * means they were gifted to me from brands but I was not paid to feature them in this video. Canadian Links: Urban Gardener: https://bit.ly/3BMn7XQ * Paint: https://bit.ly/3LoC06c * Label protector: https://fave.co/3drmppD AF Wallpaper: https://etsy.me/3xwzwwy * Desk: https://bit.ly/3QjfyMY * Rattan pendant: Homesense https://bit.ly/3EriK3e * Rug: https://bit.ly/3DxJCRM * Sofa: https://bit.ly/3zsptJ7 * Coffee table: https://bit.ly/3SzPdMC * Mirror: https://bit.ly/3RXEg6U Wall planter: https://bit.ly/3dizwte * Wall sconce: https://bit.ly/3SrLOP9 * Art print 1: https://bit.ly/3DxGYeP * Art print 2: https://bit.ly/3QTMoDQ * Art print 3: https://bit.ly/3LiSDQA * Bedding: https://etsy.me/3qGkCQN Bed cushions: https://bit.ly/3qIon87 * Bed lumbar cushion: https://bit.ly/3Bkzj0J * Frame 1: https://bit.ly/3xuACZZ * Frame 2: https://bit.ly/3xuBpds * Desk chair: Homesense https://bit.ly/3EriK3e * Entryway hooks: https://bit.ly/3BOSyRG * Bar stools: https://fave.co/3qMIhiy AF * Sofa cushion 1: https://bit.ly/3BMpSIG * Sofa cushion 2: https://bit.ly/3ROUzm5 * Floor pillows: https://fave.co/3LsnFFO AF U.S. Links: Urban Gardener: https://bit.ly/3BMn7XQ * Paint: https://bit.ly/3UfPncI * Label protector: https://fave.co/3Lmwm4b AF Wallpaper: https://etsy.me/3xwzwwy * Desk: https://bit.ly/3QjfyMY * Rattan pendant: Homesense https://bit.ly/3EriK3e * Rug: https://bit.ly/3DxJCRM * Sofa: https://bit.ly/3zsptJ7 * Coffee table: https://bit.ly/3SzPdMC * Mirror: https://bit.ly/3RXEg6U Wall planter: https://bit.ly/3dizwte * Wall sconce: https://bit.ly/3SrLOP9 * Art print 1: https://bit.ly/3DxGYeP * Art print 2: https://bit.ly/3QTMoDQ * Art print 3: https://bit.ly/3LiSDQA * Bedding: https://etsy.me/3qGkCQN Bed cushions: https://bit.ly/3qIon87 * Bed lumbar cushion: https://bit.ly/3Bkzj0J * Frame 1: https://bit.ly/3xuACZZ * Frame 2: https://bit.ly/3xuBpds * Desk chair: Homesense https://bit.ly/3EriK3e * Entryway hooks: https://bit.ly/3BOSyRG * Bar stools: https://fave.co/3QPOsge AF * Sofa cushion 1: https://bit.ly/3BMpSIG * Sofa cushion 2: https://bit.ly/3ROUzm5 * Floor pillows: https://fave.co/3qKVlER AF Let's be friends: TikTok: https://tiktok.com/@alexandragateroff... Instagram: https://instagram.com/alexandragater Pinterest: https://pinterest.ca/alexandragater Shop my Amazon store Canada: https://amazon.ca/shop/alexandragater Shop my Amazon store U.S.: https://amazon.com/shop/alexandragater Sign up to my newsletter to get decor tips and products in your inbox every week: https://alexandragater.com Retro label maker I use: https://amzn.to/2j7Ukk8 * GET IN TOUCH: Alexandra Gater P.O. Box 68555 Walmer Toronto, ON M5S 3C9 EMAIL: alexandra@alexandragater.com Thank you so much to each and every one of you for your continued support. I get to make these videos for a living, and I couldn’t be more thrilled about it. Videographer, Carla Antonio: http://carlaantonio.com Senior Editor, James Resendes: https://vimeo.com/jamesresendes Junior editor/vlog editor, Alessandra Sconza https://vimeo.com/asconza Intro designed and animated by Lindsey Deschamps: https://lindseydes.com All music sourced by licensing. All opinions are my own. It's important to hire licensed professionals for certain projects; if you're unsure or unqualified, please don't attempt any projects seen in my videos yourself.
Show less ...more

### Brownlee's Furniture

Minutes from Atlanta, we are hard to find, but worth it! Drive a little to save a lot
Ad
brownleesfurniture.com
VISIT SITE
Experiencing interruptions?
Find out why

###

•
Watch later
Add to queue